@@ -2,9 +2,9 @@
 # GNU Solfege - free ear training software
 # Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
 #
-# This program is free software; you can redistribute it and/or modify
+# This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -13,10 +13,8 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-solfege_copyright = u"Copyright  1999-2008 Tom Cato Amundsen <tca@gnu.org>, and others."
 
 import sys
 import traceback
@@ -39,6 +37,24 @@ except NameError:
 import runtime
 
 import configureoutput
+
+solfege_copyright = u"Copyright  1999-2008 Tom Cato Amundsen <tca@gnu.org>, and others."
+
+warranty = """
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""
+
 import osutils
 
 import optparse
@@ -97,22 +113,9 @@ certain conditions. Invoke as `solfege --warranty` for more information.
     sys.exit()
 
 if options.warranty:
-    print """GNU Solfege %s
-%s
-    This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License version 2
-as published by the Free Software Foundation.
-
-    This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-General Public License for more details.
-
-    You should have received a copy (refer to the file COPYING) of the
-GNU General Public License along with this program; if not, write to
-the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
-USA.
-    """ % (configureoutput.VERSION_STRING, solfege_copyright)
+    print "GNU Solfege %s" % configureoutput.VERSION_STRING
+    print solfege_copyright
+    print warranty
     sys.exit()
 
 # silent, GNOME, be silent!
@@ -584,17 +587,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         a.set_name("GNU Solfege")
         a.set_website("http://www.solfege.org")
         a.set_version(configureoutput.VERSION_STRING)
-        a.set_copyright(solfege_copyright.decode('iso-8859-1') + """
-
-GNU Solfege is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.""")
+        a.set_copyright("\n".join((solfege_copyright, warranty)))
         a.set_authors(["Tom Cato Amundsen",
               'Oliver Vollmer %s' % _("(toolbar icons)"),
               'Giovanni Chierico %s' % _("(some lessonfiles)"),
